# Translation API

::: pretok.translation.base.Translator
    options:
      show_source: true

::: pretok.translation.base.TranslationResult

::: pretok.translation.nllb.NLLBTranslator

::: pretok.translation.m2m100.M2M100Translator

::: pretok.translation.api.openai.OpenAITranslator

::: pretok.translation.api.google.GoogleTranslator

::: pretok.translation.api.deepl.DeepLTranslator

## Caching

::: pretok.translation.cache.TranslationCache

::: pretok.translation.cache.MemoryCache

::: pretok.translation.cache.RedisCache

::: pretok.translation.cache.SQLiteCache
